@@ -1,38 +1,37 @@
 $VAR1 = {
-          'floodtime' => 10,
-          'translate' => '/var/www/cgi-bin/config/translate.pl',
-          'scriptAlias' => 'cgi-bin',
+          'database' => {
+                          'CurrentDb' => 'LZE',
+                          'host' => 'localhost',
+                          'password' => 'wertvoll',
+                          'CurrentUser' => 'root',
+                          'user' => 'root',
+                          'CurrentPass' => 'wertvoll',
+                          'CurrentHost' => 'localhost',
+                          'name' => 'LZE'
+                        },
           'cgi' => {
                      'title' => 'MySQL::Admin',
-                     'bin' => '/var/www/cgi-bin',
-                     'alias' => 'cgi-bin',
                      'cookiePath' => '/',
-                     'serverName' => 'http://localhost',
-                     'DocumentRoot' => '/var/www/htdocs',
                      'style' => 'mysql',
-                     'expires' => '+1y'
+                     'serverName' => 'http://localhost',
+                     'expires' => '+1y',
+                     'alias' => 'cgi-bin',
+                     'bin' => '/var/www/cgi-bin',
+                     'DocumentRoot' => '/var/www/htdocs'
                    },
-          'defaultAction' => 'showLogin',
-          'session' => '/var/www/cgi-bin/config/session.pl',
-          'version' => '0.67',
-          'actions' => '/var/www/cgi-bin/config/actions.pl',
+          'config' => '/var/www/cgi-bin/config/settings.pl',
+          'scriptAlias' => 'cgi-bin',
           'admin' => {
-                       'firstname' => 'Dirk',
                        'email' => 'dirk.lze@gmail.com',
                        'name' => 'Lindner',
+                       'firstname' => 'Dirk',
                        'password' => 'testpass'
                      },
-          'database' => {
-                          'name' => 'LZE',
-                          'CurrentUser' => 'root',
-                          'CurrentHost' => 'localhost',
-                          'password' => 'wertvoll',
-                          'user' => 'root',
-                          'host' => 'localhost',
-                          'CurrentPass' => 'wertvoll',
-                          'CurrentDb' => 'LZE'
-                        },
           'language' => 'en',
-          'config' => '/var/www/cgi-bin/config/settings.pl'
+          'session' => '/var/www/cgi-bin/config/session.pl',
+          'version' => '0.68',
+          'translate' => '/var/www/cgi-bin/config/translate.pl',
+          'floodtime' => 10,
+          'actions' => '/var/www/cgi-bin/config/actions.pl'
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
