@@ -78,7 +78,7 @@ function menu(){
 	visible('menuContent');
 	menuAktive = true;
       }
-      var node = $("closeButton");
+      var node = $("closeMenu");
       node.addEventListener ('click', function (evt) {
 	if(menuAktive){
 	  hide('menuContent');
@@ -203,8 +203,12 @@ function setAction(n){
 }
 var tmpTxt;
 var tmpID;
-function showPopup(id){
+function showPopup(id,hideCloseButton){
 	visible('popup');
+	if(hideCloseButton)
+	  hide('closeButton');
+	else
+	  visible('closeButton');
 	tmpTxt = getText(id);
 	tmpID = id;
 	setText(id,'');
@@ -221,7 +225,7 @@ var currentId, currentTxt;
 var act ='save';
 function submitForm(node,tabId,tabTitle){
 	if(checkForm(node)){
-	  var url = "/cgi-bin/mysql.pl?";
+	  var url = "../cgi-bin/mysql.pl?";
 	  for(var i =0; i < node.elements.length;i++){
 	    if(node.elements[i].type == 'checkbox' || node.elements[i].type == 'radio'){
 		    if(node.elements[i].checked)
@@ -300,11 +304,18 @@ function setContent() {
 		    txt = txt.replace("<![CDATA[", "").replace("]]>", "");
 		setText(outID,txt);
 	      }
-	      evalId("content");
+	      evalId(outID);
 	   }else{
 		setText('content',oldpage);
 		setCurrentTab(currentId, currentTxt);
 	  }
+	  var closeButton = $("closeButton");
+	  if(!document.cookie.match('sid') ){
+	    showPopup('login',true);
+	    evalId('popupContent');
+	  }else{
+	    closeButton.addEventListener ('click',closePopup);
+	  }
         }
 }
 function evalId(id){
@@ -330,9 +341,11 @@ function loadHistory(){
 	rxObj2.exec(window.location.search);
 	var uri = RegExp.$1;
 	if(uri && action)
-	  requestURI('/cgi-bin/mysql.pl'+uri,action,translate(action),false);
+	  requestURI('cgi-bin/mysql.pl'+uri,action,translate(action),false);
 	else
-	  requestURI('/cgi-bin/mysql.pl?action=showDatabases','showDatabases','Datenbanken');
+	  requestURI('cgi-bin/mysql.pl?action=showDatabases','showDatabases','Datenbanken');
+// 	alert();
+	return true;
 }
 function translate(string){
 	var lng = navigator.language.indexOf("de") > -1 ? 'de':'en';
