@@ -16,7 +16,7 @@ use Fcntl qw(:flock);
 use Symbol;
 use URI::Escape;
 
-use CGI::Carp qw(fatalsToBrowser);
+# use CGI::Carp qw(fatalsToBrowser);
 require Exporter;
 use vars qw(
   $DefaultClass
@@ -50,10 +50,11 @@ use vars qw(
   $m_sCurrentUser
   $m_sCurrentPass
   $m_sAjax
+  $m_nSkipCaptch
 );
 @MySQL::Admin::GUI::EXPORT  = qw(ContentHeader Body ChangeDb Unique);
 @ISA                        = qw(Exporter MySQL::Admin);
-$MySQL::Admin::GUI::VERSION = '0.67';
+$MySQL::Admin::GUI::VERSION = '0.68';
 $m_bMod_perl                = ( $ENV{MOD_PERL} ) ? 1 : 0;
 local $^W = 0;
 $m_sAjax = qq(<?xml version="1.0" encoding="UTF-8"?>\n<xml>);
@@ -139,8 +140,6 @@ sub ContentHeader {
             -expires => '-1d',
             -path    => "$cookiepath"
         );
-
-        #             $m_sAjax .= '<output id="menuBar"><![CDATA[]]></output>';
         $m_sAjax .=
             '<output id="login"><![CDATA['
           . do('$m_hrSettings->{cgi}{bin}/Sidebar/exploit.pl')
@@ -159,7 +158,15 @@ sub ContentHeader {
         my $ip = remote_addr();
         my $u  = param('user');
         my $p  = param('pass');
-        if ( defined $u && defined $p && defined $ip ) {
+        $m_nSkipCaptch = 0;
+        eval('
+	use Authen::Captcha;
+        my $captcha = Authen::Captcha->new(data_folder   => "$m_hrSettings->{cgi}{bin}/config/",
+                                           output_folder => "$m_hrSettings->{cgi}{DocumentRoot}/images");
+        $m_nSkipCaptch = $captcha->check_code(param("captcha"), param("md5"));
+        ');
+        $m_nSkipCaptch = 1 if $@; # skip captcha without gd
+        if ( defined $u && defined $p && defined $ip && $m_nSkipCaptch > 0) {
             use MD5;
             my $md5 = new MD5;
             $md5->add($u);
@@ -244,18 +251,7 @@ sub Body {
         $m_oDatabase->userright($m_sUser)
       ? $m_oDatabase->userright($m_sUser)
       : 0;
-    if ( $m_sUser eq 'guest' ) {
-        my $link =
-          $m_hrSettings->{cgi}{mod_rewrite}
-          ? "/reg.html"
-          : "$ENV{SCRIPT_NAME}?action=reg";
-        my %vars = (
-            user   => 'guest',
-            action => 'login',
-        );
-        my $qstring  = createSession( \%vars );
-        my $register = translate('register');
-    }
+
 
     if ( defined $m_hrAct->{box} ) {
 
@@ -278,8 +274,11 @@ sub Body {
             $m_sContent = "";
         }
     }
-
-    do("$m_hrSettings->{cgi}{bin}/Sidebar/exploit.pl");
+    if(param('include')){
+      include(param('include'));
+    }else{
+      do("$m_hrSettings->{cgi}{bin}/Sidebar/exploit.pl");
+    }
     $m_sAjax .= '<output id="login"><![CDATA[' . $m_sContent . ']]></output>';
     $m_sContent = '';
 
